@@ -14,7 +14,7 @@ from pyunpack import Archive
 from tika import parser
 
 from texta_parsers.email_parser import EmailParser
-from texta_parsers.settings import FACE_VECTOR_FIELD_NAME, META_FIELD
+from texta_parsers.settings import META_FIELD
 from texta_parsers.tools import rar_extractor, tar_extractor, utils
 from texta_parsers.tools.extension import Extension
 from texta_parsers.tools.scanner import DocScanner
@@ -37,7 +37,6 @@ class DocParser:
                  temp_dir="",
                  languages=["est", "eng", "rus"],
                  max_file_size=100,
-                 face_analyzer=False,
                  ignore_digidoc=False):
 
         """
@@ -49,7 +48,6 @@ class DocParser:
         :param: str temp_dir: Base directory for files to be saved temporary.
         :param: [str] languages: Tika OCR languages.
         :param: int max_file_size: Maximum file size in MBs that will be parsed.
-        :param: [bool] face_analyzer: Whether face analyzer is used.
         :param: [bool] ignore_digidoc: Whether digidoc containers should be ignored.
         """
 
@@ -63,25 +61,12 @@ class DocParser:
         self.langs = languages
         self.ignore_digidoc = ignore_digidoc
         self.scanner = DocScanner()
-        self.face_analyzer = self._load_face_analyzer(face_analyzer)
 
         if (self.ignore_digidoc == False):
             if not utils.check_digidoc_exists():
                 raise FileNotFoundError("Digidoc-tool not found. Either set ignore_digidoc=True or install the tool.")
 
 
-    @staticmethod
-    def _load_face_analyzer(face_analyzer_choice):
-        """
-        Loads FaceAnalyzer.
-        """
-        if face_analyzer_choice:
-            from texta_face_analyzer.face_analyzer import FaceAnalyzer
-            return FaceAnalyzer()
-        else:
-            return None
-
-
     def create_temp_dir_for_parse(self):
         """
         Creates temp directory path.
@@ -229,12 +214,7 @@ class DocParser:
                 "X-Tika-PDFextractInlineImages": "true"
             }
         }
-        # extract faces if an image
-        is_image_file = document["extension"] in Extension.IMAGE_EXTENSIONS
-        if self.face_analyzer and is_image_file:
-            face_vectors = self.face_analyzer.vectorize_photo(document["path"])
-            if face_vectors:
-                output_document[FACE_VECTOR_FIELD_NAME] = [{"name": "UNKOWN_FACE", "vector": v} for v in face_vectors]
+
         # extract text using TIKA
         tika_output = parser.from_file(document["path"], requestOptions=tika_options)
         content = tika_output["content"]
@@ -353,8 +333,14 @@ class DocParser:
             sub_attachment[META_FIELD] = sub_file[META_FIELD]
 
             # also add potential error messages
-            if ("errors" in sub_file):
-                sub_attachment["errors"] = sub_file["errors"]
+            sub_file.setdefault(META_FIELD, {})
+            sub_file[META_FIELD].setdefault("errors", [])
+            subfile_errors = sub_file[META_FIELD]["errors"]
+
+            if subfile_errors:
+                sub_attachment.setdefault(META_FIELD, {})
+                sub_attachment[META_FIELD].setdefault("errors", [])
+                sub_attachment[META_FIELD]["errors"].extend(subfile_errors)
 
             # in case the attachment was an archive and contained multiple files,
             # add index number to attachment id to show it 
@@ -408,7 +394,8 @@ class DocParser:
             # parse all files
             for meta in docs_to_parse:
                 if (not self._file_size_ok(self.max_file_size, meta)):
-                    meta["errors"] = "File too large for parsing."
+                    meta.setdefault("errors", [])
+                    meta["errors"].append("File too large for parsing.")
                     yield {META_FIELD: meta}
 
                 # email parser handles all the errors and logs uncaught
@@ -436,14 +423,18 @@ class DocParser:
                                         extracted_attachments += self._parse_attachment(attachment)
                                     except:
                                         exc_type, value, _ = sys.exc_info()
-                                        error_msg = "{}: {}".format(exc_type.__name__, value)
-                                        attachment[META_FIELD]["errors"] = error_msg
+                                        error_msg = "DocParser - Content - {}: {}".format(exc_type.__name__, value)
+
+                                        attachment.setdefault(META_FIELD, {})
+                                        attachment[META_FIELD].setdefault("errors", [])
+                                        attachment[META_FIELD]["errors"].append(error_msg)
+
                                         extracted_attachments += [attachment]
                                         # Remove bytes that can be left in because of exceptions as they can
                                         # not be parsed by Elasticsearch.
                                         self._overwrite_bytes_content(attachment)
 
-                                # save attachments if specified
+                                    # save attachments if specified
                                     for attachment in extracted_attachments:
                                         if ("subject" not in attachment):  # is actually mail, do not save it (already in email_parser if specified so!)
                                             self.save_attachment(attachment)
@@ -469,8 +460,9 @@ class DocParser:
                             yield item
                     except:
                         exc_type, value, _ = sys.exc_info()
-                        error_msg = "{}: {}".format(exc_type.__name__, value)
-                        meta["errors"] = error_msg
+                        error_msg = "DocParser - Content - {}: {}".format(exc_type.__name__, value)
+                        meta.setdefault("errors", [])
+                        meta["errors"].append(error_msg)
                         yield {META_FIELD: meta}
 
                 # parse everything else
@@ -483,8 +475,9 @@ class DocParser:
                             yield parsed_document
                     except:
                         exc_type, value, _ = sys.exc_info()
-                        error_msg = "{}: {}".format(exc_type.__name__, value)
-                        meta["errors"] = error_msg
+                        error_msg = "DocParser - Content - {}: {}".format(exc_type.__name__, value)
+                        meta.setdefault("errors", [])
+                        meta["errors"].append(error_msg)
                         yield {META_FIELD: meta}
 
 
