@@ -6,6 +6,7 @@ from random import getrandbits
 
 import magic
 
+from texta_parsers.settings import META_FIELD
 from texta_parsers.tools.message import AttachmentParser, BodyParser, HeaderParser
 from texta_parsers.tools.pst_extractor import check_readpst_exists, extract_pst_file
 
@@ -152,12 +153,11 @@ class EmailParser():
 
         attachments = b_parser.parse_attachments(msg_id)
 
-        # concatenate errors
-        header_fails = h_parser.fails
-        header_fails.update(b_parser.fails)
-
-        if header_fails != {}:
-            msg_data["errors"] = header_fails
+        failures = h_parser.fails + b_parser.fails
+        if failures:
+            msg_data.setdefault(META_FIELD, {})
+            msg_data[META_FIELD].setdefault("errors", [])
+            msg_data[META_FIELD]["errors"].extend(failures)
 
         return msg_data, attachments
 
