@@ -33,14 +33,19 @@ class Extension:
 
 
     @staticmethod
-    def is_supported(file, file_name=None):
+    def is_supported(file, file_name=None, allowed_extensions=None):
         """
         Tests if file is supported.
+        :param file: either bytes or string to filepath.
+        :param file_name: if file is bytes then file_name is always given.
+        :param allowed_extensions: which extensions would be allowed.
         :return: bool.
         """
+        if not allowed_extensions:
+            allowed_extensions = Extension.KNOWN_EXTENSIONS
         try:
             prediction = Extension.predict(file, file_name=file_name)
-            if prediction in Extension.KNOWN_EXTENSIONS:
+            if prediction in allowed_extensions:
                 return True
         except exceptions.UnsupportedFileError:
             return False
